// Original author: Francois Henrotte

// All dimensions in meters and rads

Lc = 0.0009 ;           // Base char length
Z  = 0.0 ;              // Z-coord

// Stator data

nbs = 36 ;		// Num. of poles
dths = 2 * Pi / nbs ;   // Ang. shift between 2 poles.

// Pi is the only constant predefined in Gmsh

th0s = dths / 2 ;       // Angular pos.
des = 0.1529 ;          // Ext. diam.
res = des / 2 ;		  
dis = 0.09208 ;         // Int. diam.
ris = dis / 2 ;		  
			  
hs = 0.0153 ;           // Pole height
h1s = 0.000762 ;        // Dist. intersection rec.-int. circle
d1s = 0.00636 ;         // Diam. sup. circle
r1s = d1s / 2 ;		  
rc1s = 0.00084 ;        // Radius convex rec.
rc2s = 0.000508 ;       // Radius concave rec.
e1s = 0.0025 ;          // Dist. between 2 sides at int diam
e2s = 0.00424 ;         // Dist. between 2 sides at 1st rec.

// Rotor data

nbr = 32 ;		// Num. of poles
dthr = 2 * Pi / nbr ;   // Angular shift betw. 2 poles
			  
th0r = dths / 2 ;       // Ang. pos. rotor
gap = 0.00080 ;         // Air gap width
espa = 0.0015 ;         // Dist. stator-pole top
der = 0.09208 ;         // Ext. diam rotor
rer = der / 2 ;		  
dir = 0.03175 ;         // Diam. int. 
rir = dir / 2 ;		  
			  
hr = 0.01425 ;          // Pole height
d1r = 0.00426 ;         // Diam. sup circle
r1r = d1r / 2 ;		  
d2r = 0.00213 ;         // Diam. inf. circle
r2r = d2r / 2 ;		  
			  
dist = rer - espa ;	// Radial dist. of intersect. point

/* 'newp' is a meta variable defining a new point number for you.
   This is mostly useful with included files. There is also 'newreg'
   which defines a new region number (that is, everything that is not
   a point). */

pAxe = newp ; Point(pAxe) = { 0. , 0. , 0., Lc} ;

// axis

p1 = newp ; Point(p1) = { rir, 0. , 0., 15*Lc} ;
p2 = newp ; Point(p2) = { 0. , rir, 0., 15*Lc} ;
p3 = newp ; Point(p3) = { -rir, 0. , 0., 15*Lc} ;
p4 = newp ; Point(p4) = { 0. , -rir, 0., 15*Lc} ;

//lin1 = newreg ;	Line(lin1)   = {pAxe,p1} ;
arc1 = newreg ;	Circle(arc1) = {p1,pAxe,p2} ;
arc2 = newreg ;	Circle(arc2) = {p2,pAxe,p3} ;
arc3 = newreg ;	Circle(arc3) = {p3,pAxe,p4} ;
arc4 = newreg ;	Circle(arc4) = {p4,pAxe,p1} ;
//lin2 = newreg ;	Line(lin2)   = {p2, pAxe} ;

//reg1 = newreg ; Line Loop(reg1) = {lin1,arc1,lin2} ;
//reg2 = newreg ; Plane Surface(reg2) = {reg1} ;

// Rotor lateral sides

p5 = newp ; Point(p5) = { rer-gap, 0.     , 0., Lc} ;
p6 = newp ; Point(p6) = { 0.     , rer-gap, 0., Lc} ;
p7 = newp ; Point(p7) = { -rer+gap, 0.     , 0., Lc} ;
p8 = newp ; Point(p8) = { 0.     , -rer+gap, 0., Lc} ;


//lin3 = newreg ; Line(lin3)   = {p1, p3} ;
arc5 = newreg ; Circle(arc5) = {p5,pAxe,p6} ;
arc6 = newreg ; Circle(arc6) = {p6,pAxe,p7} ;
arc7 = newreg ; Circle(arc7) = {p7,pAxe,p8} ;
arc8 = newreg ; Circle(arc8) = {p8,pAxe,p5} ;
//lin4 = newreg ;	Line(lin4)   = {p4, p2} ;

// Air gap

//p5 = newp ; Point(p5) = { ris, 0. , 0., Lc} ;
//p6 = newp ; Point(p6) = { 0. , ris, 0., Lc} ;

//lin5 = newreg ; Line(lin5) = {p3, p5} ;
//lin6 = newreg ; Line(lin6) = {p6, p4} ;

// Stator exterior

p9 = newp ; Point(p9) = { res, 0. , 0. , 15*Lc } ;
p10 = newp ; Point(p10) = { 0. , res, 0. , 15*Lc } ;
p11 = newp ; Point(p11) = { -res, 0. , 0. , 15*Lc } ;
p12 = newp ; Point(p12) = { 0. , -res, 0. , 15*Lc } ;

//lin7 = newreg ;	Line(lin7)   = {p5, p7} ;
arc9 = newreg ;	Circle(arc9) = {p9,pAxe,p10} ;
arc10 = newreg ;	Circle(arc10) = {p10,pAxe,p11} ;
arc11 = newreg ;	Circle(arc11) = {p11,pAxe,p12} ;
arc12 = newreg ;	Circle(arc12) = {p12,pAxe,p9} ;
//lin8 = newreg ;	Line(lin8)   = {p8, p6} ;

//PP1 = p5 ; PPB = p6 ; 

// 8 rotor poles

D1 = dist ; 
H  = hr ; 
R1 = r1r ; 
R2 = r2r ; 

/* You can include files with the 'Include' command. Note that *ALL*
   variables in Gmsh are global. Including a file is similar to paste
   its content where the include command is located. */

i = 0;

For(1:32)
  i++ ;
  th = th0r + (i - 1) * dthr ;
  Include "machine.i1" ; 
EndFor

// 9 stator poles

dth = dths ;
D2  = ris ;
H   = hs ;
R1 = r1s ;
R2 = rc1s ;
R3 = rc2s ;
E1 = e1s ;
E2 = e2s ;
H1 = h1s ;

i = 1 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP2 = p1 ; PP3 = p9 ;
i = 2 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP4 = p1 ; PP5 = p9 ;
i = 3 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP6 = p1 ; PP7 = p9 ;
i = 4 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP8 = p1 ; PP9 = p9 ;
i = 5 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP10 = p1 ; PP11 = p9 ;
i = 6 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ;
PP12 = p1 ; PP13 = p9 ;
i = 7 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP14 = p1 ; PP15 = p9 ;
i = 8 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP16 = p1 ; PP17 = p9 ;
i = 9 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP18 = p1 ; PP19 = p9 ;
i = 10 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP20 = p1 ; PP21 = p9 ;
i = 11 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP22 = p1 ; PP23 = p9 ;
i = 12 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP24 = p1 ; PP25 = p9 ;
i = 13 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP26 = p1 ; PP27 = p9 ;
i = 14 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP28 = p1 ; PP29 = p9 ;
i = 15 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP30 = p1 ; PP31 = p9 ;
i = 16 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP32 = p1 ; PP33 = p9 ;
i = 17 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ;
PP34 = p1 ; PP35 = p9 ;
i = 18 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP36 = p1 ; PP37 = p9 ;
i = 19 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP38 = p1 ; PP39 = p9 ;
i = 20 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP40 = p1 ; PP41 = p9 ;
i = 21 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP42 = p1 ; PP43 = p9 ;
i = 22 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP44 = p1 ; PP45 = p9 ;
i = 23 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP46 = p1 ; PP47 = p9 ;
i = 24 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ;
PP48 = p1 ; PP49 = p9 ;
i = 25 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP50 = p1 ; PP51 = p9 ;
i = 26 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP52 = p1 ; PP53 = p9 ;
i = 27 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP54 = p1 ; PP55 = p9 ;
i = 28 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP56 = p1 ; PP57 = p9 ;
i = 29 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP58 = p1 ; PP59 = p9 ;
i = 30 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP60 = p1 ; PP61 = p9 ;
i = 31 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ;
PP62 = p1 ; PP63 = p9 ;
i = 32 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP64 = p1 ; PP65 = p9 ;
i = 33 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP66 = p1 ; PP67 = p9 ;
i = 34 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP68 = p1 ; PP69 = p9 ;
i = 35 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP70 = p1 ; PP71 = p9 ;
i = 36 ; th = th0s + (i - 1) * dths ;
Include "machine.i2" ; 
PP72 = p1 ; PP73 = p9 ;


//lin1 = newreg ; Line(lin1) = {PP1 , PP2 } ;
lin1 = newreg ; Line(lin1) = {PP3 , PP4 } ;
lin1 = newreg ; Line(lin1) = {PP5 , PP6 } ;
lin1 = newreg ; Line(lin1) = {PP7 , PP8 } ;
lin1 = newreg ; Line(lin1) = {PP9 , PP10} ;
lin1 = newreg ; Line(lin1) = {PP11, PP12} ;
lin1 = newreg ; Line(lin1) = {PP13, PP14} ;
lin1 = newreg ; Line(lin1) = {PP15, PP16} ;
lin1 = newreg ; Line(lin1) = {PP17, PP18} ;
//lin1 = newreg ; Line(lin1) = {PP19, PPB } ; // Borrar PPB
lin1 = newreg ; Line(lin1) = {PP19, PP20} ;
lin1 = newreg ; Line(lin1) = {PP21, PP22} ;
lin1 = newreg ; Line(lin1) = {PP23, PP24} ;
lin1 = newreg ; Line(lin1) = {PP25, PP26} ;
lin1 = newreg ; Line(lin1) = {PP27, PP28} ;
lin1 = newreg ; Line(lin1) = {PP29, PP30} ;
lin1 = newreg ; Line(lin1) = {PP31, PP32} ;
lin1 = newreg ; Line(lin1) = {PP33, PP34} ;
lin1 = newreg ; Line(lin1) = {PP35, PP36} ;
lin1 = newreg ; Line(lin1) = {PP37, PP38} ;
lin1 = newreg ; Line(lin1) = {PP39, PP40} ;
lin1 = newreg ; Line(lin1) = {PP41, PP42} ;
lin1 = newreg ; Line(lin1) = {PP43, PP44} ;
lin1 = newreg ; Line(lin1) = {PP45, PP46} ;
lin1 = newreg ; Line(lin1) = {PP47, PP48} ;
lin1 = newreg ; Line(lin1) = {PP49, PP50} ;
lin1 = newreg ; Line(lin1) = {PP51, PP52} ;
lin1 = newreg ; Line(lin1) = {PP53, PP54} ;
lin1 = newreg ; Line(lin1) = {PP55, PP56} ;
lin1 = newreg ; Line(lin1) = {PP57, PP58} ;
lin1 = newreg ; Line(lin1) = {PP59, PP60} ;
lin1 = newreg ; Line(lin1) = {PP61, PP62} ;
lin1 = newreg ; Line(lin1) = {PP63, PP64} ;
lin1 = newreg ; Line(lin1) = {PP65, PP66} ;
lin1 = newreg ; Line(lin1) = {PP67, PP68} ;
lin1 = newreg ; Line(lin1) = {PP69, PP70} ;
lin1 = newreg ; Line(lin1) = {PP71, PP72} ;
lin1 = newreg ; Line(lin1) = {PP73, PP2} ;

//Line Loop(145) = {8,-2,6,7};
//Plane Surface(146) = {145,68,61,54,47,40,33,26,19};

//Line Loop(147) = {-7,9,133,-74,134,-81,135,-88,136,-95,137,-102,
//                  138,-109,139,-116,140,-123,141,-130,142,10};
//Plane Surface(148) = {147};

//Line Loop(149) = {70,71,72,73,134,77,78,79,80,135,84,85,86,87,136,
//                  91,92,93,94,137,98,99,100,101,138,105,106,107,108,
//                  139,112,113,114,115,140,119,120,121,122,141,126,127,
//                  128,129,142,-13,-12,-11,133};
//Plane Surface(150) = {149};

/* One should define physical regions to specify what to
   save. Otherwise, only mesh points will be output in the mesh
   file. */
Line Loop(525) = {1, 2, 3, 4};
Plane Surface(526) = {525};
Line Loop(527) = {5, 6, 7, 8};
Plane Surface(528) = {18, 25, 32, 39, 46, 53, 60, 67, 74, 81, 88, 95, 102, 109, 116, 123, 130, 137, 144, 151, 158, 165, 172, 179, 186, 193, 200, 207, 214, 221, 228, 235, 525, 527};
Line Loop(529) = {496, -297, 497, -304, 498, -311, 499, -318, 500, -325, 501, -332, 502, -339, 503, -346, 504, -353, 505, -360, 506, -367, 507, -374, 508, -381, 509, -388, 510, -395, 511, -402, 512, -409, 513, -416, 514, -423, 515, -430, 516, -437, 517, -444, 518, -451, 519, -458, 520, -465, 521, -472, 522, -479, 523, -486, 524, -241, 489, -248, 490, -255, 491, -262, 492, -269, 493, -276, 494, -283, 495, -290, 496, -297, 497, -304};
Plane Surface(530) = {527, 529};
Line Loop(531) = {10, 11, 12, 9};
Line Loop(532) = {310, 499, 314, 315, 316, 317, 500, 321, 322, 323, 324, 501, 328, 329, 330, 331, 502, 335, 336, 337, 338, 503, 342, 343, 344, 345, 504, 349, 350, 351, 352, 505, 356, 357, 358, 359, 506, 363, 364, 365, 366, 507, 370, 371, 372, 373, 508, 377, 378, 379, 380, 509, 384, 385, 386, 387, 510, 391, 392, 393, 394, 511, 398, 399, 400, 401, 512, 405, 406, 407, 408, 513, 412, 413, 414, 415, 514, 419, 420, 421, 422, 515, 426, 427, 428, 429, 516, 433, 434, 435, 436, 517, 440, 441, 442, 443, 518, 447, 448, 449, 450, 519, 454, 455, 456, 457, 520, 461, 462, 463, 464, 521, 468, 469, 470, 471, 522, 475, 476, 477, 478, 523, 482, 483, 484, 485, 524, 237, 238, 239, 240, 489, 244, 245, 246, 247, 490, 251, 252, 253, 254, 491, 258, 259, 260, 261, 492, 265, 266, 267, 268, 493, 272, 273, 274, 275, 494, 279, 280, 281, 282, 495, 286, 287, 288, 289, 496, 293, 294, 295, 296, 497, 300, 301, 302, 303, 498, 307, 308, 309};
Plane Surface(533) = {531, 532};

// Infinito
Ri = res * 2; // radio de la circunferencia infinito
Point(1001) = {Ri, 0, 0, Lc*30};
Point(1002) = {0, Ri, 0, Lc*30};
Point(1003) = {-Ri, 0, 0, Lc*30};
Point(1004) = {0, -Ri, 0, Lc*30};
// circulos
Circle(1001) = {1001, pAxe, 1002};
Circle(1002) = {1002, pAxe, 1003};
Circle(1003) = {1003, pAxe, 1004};
Circle(1004) = {1004, pAxe, 1001};
Line Loop(1005) = {1001, 1002, 1003, 1004};
Plane Surface(1006) = {531, 1005};

// Elementos fisicos
Physical Surface(1007) = {526};
Physical Surface(1008) = {528};
Physical Surface(1009) = {68, 61, 54, 47, 40, 33, 26, 19, 236, 229, 222, 215, 208, 201, 194, 187, 180, 173, 166, 159, 152, 145, 138, 131, 124, 117, 110, 103, 96, 89, 82, 75};
Physical Surface(1010) = {533};
Physical Surface(1011) = {362, 355, 348, 341, 334, 327, 320, 313, 306, 299, 292, 285, 278, 271, 264, 257, 250, 243, 488, 481, 474, 467, 460, 453, 446, 439, 432, 425, 418, 411, 404, 397, 390, 383, 376, 369};
Physical Surface(1012) = {1006};
Physical Line(1013) = {1002, 1003, 1004, 1001};
Physical Surface(1013) = {530};